#ifndef __BSP_H__
#define __BSP_H__

#include <ubb/ubb.h>

/* Pin assignments:
 *
 * Sniffer  UBB   EM027AS012
 * -------  ----  -----------
 * DAT2     DAT2   4 (MOSI)
 * CD       DAT3   6 (SSEL)
 * CMD      CMD   11 (PWM)
 * VCC      VDD   13 (PANEL)
 * CLK      CLK    3 (SCK)
 * GND      GND
 * DAT0     DAT0  12 (RESET)
 * DAT1     DAT1  14 (DIS)
 *
 * General connections:
 *
 *                EM027AS012
 *                ----------
 *                 1 (GND)
 *                 2 (3V3)
 */

#define EPD_MOSI  UBB_DAT2
#define EPD_SSEL  UBB_DAT3
#define EPD_PWM   UBB_CMD
#define EPD_SCK   UBB_CLK
#define EPD_RESET UBB_DAT0
#define EPD_DIS   UBB_DAT1

/* Board-specific interface functions. */

void bsp_init();
void bsp_InitDisplayHardware();
void bsp_PowerOn();
void bsp_pwm_active(uint16_t delayInMs);
void bsp_Shutdown();
void bsp_spiInit();
void bsp_writeToDisplay(uint8_t *data, uint16_t len);
void bsp_delayMs(uint32_t ms);
void bsp_delayUs(uint32_t us);
uint32_t bsp_getMsTicks();
int16_t bsp_getTemp();

#endif /* __BSP_H__ */
